wagoe.workflow.shell.admin-adapter

The admin's IEntityWorkflows port over this module's store (BOU-563). Here and not in the admin, because this library depends on the admin and not the other way round.

The admin's `IEntityWorkflows` port over this module's store (BOU-563).
Here and not in the admin, because this library depends on the admin and
not the other way round.
raw docstring

create-entity-workflowsclj

(create-entity-workflows store)
source

cljdoc builds & hosts documentation for Clojure/Script libraries