Clojure only.

wagoe.workflow.shell.module-wiring

Integrant lifecycle management for the workflow module.

Config keys:

:wagoe/workflow-db-schema {:ctx (ig/ref :wagoe/db-context)}

:wagoe/workflow Minimal config (no side-effects): {:db-ctx (ig/ref :wagoe/db-context) :db-schema (ig/ref :wagoe/workflow-db-schema)}

Full config (with jobs side-effects): {:db-ctx (ig/ref :wagoe/db-context) :db-schema (ig/ref :wagoe/workflow-db-schema) :job-queue (ig/ref :wagoe/job-queue) :guard-registry {}}

:wagoe/workflow-routes {:workflow-service (ig/ref :wagoe/workflow) :user-service (ig/ref :wagoe/user-service)}

Returns {:api [...] :web [...] :static []} for composition by the HTTP handler.

Integrant lifecycle management for the workflow module.

Config keys:

:wagoe/workflow-db-schema
  {:ctx (ig/ref :wagoe/db-context)}

:wagoe/workflow
  Minimal config (no side-effects):
    {:db-ctx    (ig/ref :wagoe/db-context)
     :db-schema (ig/ref :wagoe/workflow-db-schema)}

  Full config (with jobs side-effects):
    {:db-ctx        (ig/ref :wagoe/db-context)
     :db-schema     (ig/ref :wagoe/workflow-db-schema)
     :job-queue     (ig/ref :wagoe/job-queue)
     :guard-registry {}}

:wagoe/workflow-routes
  {:workflow-service (ig/ref :wagoe/workflow)
   :user-service     (ig/ref :wagoe/user-service)}

  Returns {:api [...] :web [...] :static []} for composition
  by the HTTP handler.
raw docstring

ig-configclj

(ig-config _settings _ctx)

This module's Integrant entries, for wagoe.platform.shell.system.config.

:wagoe/workflow-db-schema creates the module's tables. Applications used to enumerate this graph by hand and none of them wired it, so wagoe add workflow gave you a service whose tables did not exist (BOU-326).

This module's Integrant entries, for `wagoe.platform.shell.system.config`.

:wagoe/workflow-db-schema creates the module's tables. Applications used to
enumerate this graph by hand and none of them wired it, so `wagoe add
workflow` gave you a service whose tables did not exist (BOU-326).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries